==> lein-template-0.1.1.jar: leiningen/new/fmn/project.clj <==
(defproject {{fq-name}} "{{project-version}}"
  :description "FIXME"
  :dependencies [[org.clojure/clojure "{{clojure-version}}"]
                 [org.clojure/data.json "{{clojure-data.json-version}}"]
                 [ring "{{ring-version}}"]
                 [ring/ring-json "{{ring-json-version}}"]
                 [http-kit "{{http-kit-version}}"]
                 [compojure "{{compojure-version}}"]
                 [juggler "{{juggler-version}}"]
                 [com.novemberain/monger "{{monger-version}}"]
                 [org.clojure/clojurescript "{{clojurescript-version}}"]
                 [liberator "{{liberator-version}}"]]
  :profiles {:dev {:plugins [lein-cljsbuild "{{lein-cljsbuild-version}}"]}}
  :cljsbuild {:builds [{:source-paths ["{{cljs-source-path}}"]
                        :compiler {:output-to "{{cljs-output}}"
                                   :optimizations :advanced
                                   :pretty-print false}}
                       {:source-paths ["{{cljs-source-path}}"]
                        :compiler {:output-to "{{cljs-dev-output}}"
                                   :optimizations :whitespace
                                   :pretty-print true}}]}
  :source-paths ["{{clj-source-path}}"]
  :apps-config {:dev {:server {:ip "0.0.0.0"
                               :port 8080
                               :thread 4
                               :worker-name-prefix "worker-"
                               :queue-size 20000
                               :max-body 8388608
                               :max-line 4096}
                      :db {:host "127.0.0.1"
                           :port 27017}}
                :prod {:server {:ip "0.0.0.0"
                               :port 8080
                               :thread 4
                               :worker-name-prefix "worker-"
                               :queue-size 20000
                               :max-body 8388608
                               :max-line 4096}
                       :db {:host "127.0.0.1"
                           :port 27017}}})

==> lein-template-0.1.3.jar: leiningen/new/fmn/project.clj <==
(defproject {{fq-name}} "{{project-version}}"
  :description "FIXME"
  :dependencies [[org.clojure/clojure "{{clojure-version}}"]
                 [org.clojure/data.json "{{clojure-data-json-version}}"]
                 [ring "{{ring-version}}"]
                 [ring/ring-json "{{ring-json-version}}"]
                 [http-kit "{{http-kit-version}}"]
                 [compojure "{{compojure-version}}"]
                 [juggler "{{juggler-version}}"]
                 [com.novemberain/monger "{{monger-version}}"]
                 [org.clojure/clojurescript "{{clojurescript-version}}"]
                 [liberator "{{liberator-version}}"]]
  :profiles {:dev {:plugins [lein-cljsbuild "{{lein-cljsbuild-version}}"]}}
  :cljsbuild {:builds [{:source-paths ["{{cljs-source-path}}"]
                        :compiler {:output-to "{{cljs-output}}"
                                   :optimizations :advanced
                                   :pretty-print false}}
                       {:source-paths ["{{cljs-source-path}}"]
                        :compiler {:output-to "{{cljs-dev-output}}"
                                   :optimizations :whitespace
                                   :pretty-print true}}]}
  :source-paths ["{{clj-source-path}}"]
  :apps-config {:dev {:server {:ip "0.0.0.0"
                               :port 8080
                               :thread 4
                               :worker-name-prefix "worker-"
                               :queue-size 20000
                               :max-body 8388608
                               :max-line 4096}
                      :db {:host "127.0.0.1"
                           :port 27017}}
                :prod {:server {:ip "0.0.0.0"
                               :port 8080
                               :thread 4
                               :worker-name-prefix "worker-"
                               :queue-size 20000
                               :max-body 8388608
                               :max-line 4096}
                       :db {:host "127.0.0.1"
                            :port 27017}}})
